function X = SimplexProj(Y,a)
% project Y to the simplex Dn
% Dn = { x : x >= 0, sum(x) = a}
%
% default "a" is 1.
%
% According to the paper of 
% Weiran Wang and Miguel A. Carreira-Perpinan, 
% "Projection onto the probability simplex: An efficient algorithm with a
% simple proof, and an application"
%
% Modified by Filip S. (2019) for Y as a 3D array of 2D images or as a 4D
% array with the third dimension running over images

if (nargin < 2) || isempty(a)
    a = 1;
end

S = size(Y);
if length(S) == 4
    Y = (reshape(permute(Y,[1 2 4 3]),[],size(Y,3))).';
else
    Y = (reshape(Y,[],size(Y,3))).';
end
[N,D] = size(Y);
X = sort(Y,2,'descend');
Xtmp = (cumsum(X,2)-a).*(1./(1:D));
X = max(bsxfun(@minus,Y,Xtmp(sub2ind([N,D],(1:N)',sum(X>Xtmp,2)))),0);
if length(S) == 4
    X = reshape(X.',S([1,2,4,3]));
    X = permute(X,[1 2 4 3]);
else
    X = reshape(X.',S);
end
