function [r, j] = dyksproj2Set(p,maxiter, reltol, maxc)
% Dykstra Projection Algorithm to finitely many convex sets (implementation witout
% quadprog)
% p ... intensity values of pixels; size 4xN, ordered [m,r,g,b] and 
%       N is the total number of pixels
% maxiter ... maximum number of iterations (default 1000) 
% reltol ... relative tolerance (default 1e-4)
% maxc ... end point of the convex set (corresponds to the maximum allowed color)
%
% r ... p projected to the convex set
% j ... number of iterations needed to reach reltol

if nargin<2 || isempty(maxiter)
    maxiter = 1000;
end
if nargin<3 || isempty(reltol)
    reltol = 1e-4;
end
if nargin<4 || isempty(maxc)
    maxc = [1 1 1];
end

%% [m,r,g] - image with two color channels; test
%Ap = [1, 0, 0; 0, -1, 0; -1, 1, 0; 0, 0, -1; -1, 0, 1];
%bp = [1, 0, 0, 0, 0].';

%% [m,r,g,b] - color image
Ap = [1, 0, 0, 0; ...
    0, -1, 0, 0; ...
    0, 0, -1, 0; ...
    0, 0, 0, -1; ...
    -maxc(1), 1, 0, 0; ...
    -maxc(2), 0, 1, 0; ...
    -maxc(3), 0, 0, 1];
bp = [1, 0, 0, 0, 0, 0, 0].';

n = sqrt(sum(Ap.^2,2));
Ap = Ap./n;
bp = bp./n;
np = norm(p(:));
N = size(Ap,1);
q = cell(1,N);
[q{:}] = deal(zeros(size(p)));
r = p;
j = 0;
while j<maxiter
    for i = 1:N
        oldr = r;
        r = r+q{i};
        d = Ap(i,:)*(r) - bp(i); 
        m = find(d>0);
        if ~isempty(m)
            r(:,m) = r(:,m) - Ap(i,:).'*d(m);
        end
        q{i} = oldr + q{i} - r;
    end
    j = j+1;
    if norm(oldr(:)-r(:))/np < reltol
        break;
    end
end
%disp(j);
end

